@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 def plot(gsn, gss, gsc='', gls='', pc=0.01, adj=True, prm=10000, gsz=10**6,
-         deg=10**6, spl=2, nsz=300, eds=5, lbs=9, hmt='binary', cft='', ctt='',
-         csp='', nwf='', hmf='', gml=''):
+         deg=10**6, spl=2, sae=False, nsz=300, eds=5, lbs=9, hmt='binary', 
+         cft='', ctt='', csp='', nwf='', hmf='', gml=''):
     """Kiwi: a tool to combine gene-set analyses with biological networks.
     
     Produces a network plot and a heatmap given a gene-set interaction network, 
@@ -63,6 +63,12 @@ def plot(gsn, gss, gsc='', gls='', pc=0.01, adj=True, prm=10000, gsz=10**6,
           in the interaction network after which no edge would connect them. This 
           can be interpreted as the threshold after which two genesets are 
           considered unrelated. [default = 2]
+          
+    sae : Show all edges. This flag controls if all but the best edges (defined
+          by having the shortest path length) for each node should be removed 
+          before plotting. If set to True, all edges (passing the spl cutoff)
+          will be drawn. If set to False, only the best edges for each node will
+          be included. [default = False]
 
 
     PLOTTING PARAMETERS
@@ -80,7 +86,7 @@ def plot(gsn, gss, gsc='', gls='', pc=0.01, adj=True, prm=10000, gsz=10**6,
           white when set to “binary” or to a blue-to-red colormap according to 
           the fold-change when set to “values”. [default = 'binary']
 
-    ctf : This flag reports the annotation source for the genes in the GSA run 
+    cft : This flag reports the annotation source for the genes in the GSA run 
           (e.g. Ensembl). It should match the annotation sources listed in 
           mygene.info (e.g. ensembl.gene). [default = '']
 
@@ -225,31 +231,33 @@ def plot(gsn, gss, gsc='', gls='', pc=0.01, adj=True, prm=10000, gsz=10**6,
         # Import the gene-metabolite information:
         content      = np.genfromtxt(GMfile,dtype=None,delimiter='\t')
         metList      = np.copy(M.metaboliteList)
-        genenameList = []
+        #genenameList = []
         for met in metList:
             genenames       = np.unique(np.squeeze(np.asarray((content[np.where(content[:,0]==met.name)[0],1]))))
-            genenamesAsList = [g for g in genenames]
-            if genenamesAsList in genenameList:
+            ##The following code is commented due to removal of gene-set lumping...
+            #genenamesAsList = [g for g in genenames]
+            #if genenamesAsList in genenameList:
+            #    M.removeMetabolite(met)
+            #    genenameList.append([np.nan])
+            #    metInd = np.where([gl == genenamesAsList for gl in genenameList])[0][0]
+            #    kiwiF.updateLabel(metList[metInd])
+            #else:
+            #    genenameList.append(genenamesAsList)
+            ##The code chunk below was originally part of the above else statement...
+            # Check if some genes were excluded by the upstream GSA from a metabolite due to missing stats
+            if len(genenames) > maxGSsize:
                 M.removeMetabolite(met)
-                genenameList.append([np.nan])
-                metInd = np.where([gl == genenamesAsList for gl in genenameList])[0][0]
-                kiwiF.updateLabel(metList[metInd])
             else:
-                genenameList.append(genenamesAsList)
-                # Check if some genes were excluded by the upstream GSA from a metabolite due to missing stats
-                if len(genenames) > maxGSsize:
-                    M.removeMetabolite(met)
-                else:
-                    for genename in genenames:
-                        gene = G.getGene(genename)
-                        if isinstance(gene,kiwiC.Gene):
-                            met.addGene(gene)
-                        else:
-                            newGene = kiwiC.Gene(genename)
-                            newGene.addGeneStats(p=np.nan,FC=np.nan)
-                            G.addGene(newGene)
-                            met.addGene(newGene) 
-    
+                for genename in genenames:
+                    gene = G.getGene(genename)
+                    if isinstance(gene,kiwiC.Gene):
+                        met.addGene(gene)
+                    else:
+                        newGene = kiwiC.Gene(genename)
+                        newGene.addGeneStats(p=np.nan,FC=np.nan)
+                        G.addGene(newGene)
+                        met.addGene(newGene) 
+
     # Construct a dense plot graph:
     PG = nx.Graph()
     PG.add_nodes_from(M.metaboliteList)
@@ -267,17 +275,19 @@ def plot(gsn, gss, gsc='', gls='', pc=0.01, adj=True, prm=10000, gsz=10**6,
     edges_to_remove = [e for e in PG.edges() if PG[e[0]][e[1]]['shortest_path_length']>splcutoff]
     PG.remove_edges_from(edges_to_remove)
     
-    # Keep only the best edge/s for each node:
-    all_edges_to_save = []
-    for met in PG.nodes():
-        minspl = float('Inf')
-        for e in nx.edges(PG,met):
-            minspl = min(minspl,PG[e[0]][e[1]]['shortest_path_length'])
-        edges_to_save = [e for e in nx.edges(PG,met) if PG[e[0]][e[1]]['shortest_path_length'] == minspl]
-        for e in edges_to_save:
-            all_edges_to_save.append(e)
-    PG.remove_edges_from([e for e in PG.edges() if e not in all_edges_to_save 
-        and (e[1],e[0]) not in all_edges_to_save])
+    # Keep only the best edge/s for each node (if not argument sae=True):
+    if not sae:
+        print "Help! You are not using sae!!"
+        all_edges_to_save = []
+        for met in PG.nodes():
+            minspl = float('Inf')
+            for e in nx.edges(PG,met):
+                minspl = min(minspl,PG[e[0]][e[1]]['shortest_path_length'])
+            edges_to_save = [e for e in nx.edges(PG,met) if PG[e[0]][e[1]]['shortest_path_length'] == minspl]
+            for e in edges_to_save:
+                all_edges_to_save.append(e)
+        PG.remove_edges_from([e for e in PG.edges() if e not in all_edges_to_save 
+            and (e[1],e[0]) not in all_edges_to_save])
     
     # Get edge width for plotting:
     edge_width = kiwiF.getEdgeProperty(PG,'weight')
